@@ -218,6 +218,17 @@ pub fn initialize() -> App<'static, 'static> {
                     "File extension(s) to search for (ex: -x php -x pdf js)",
                 ),
         )
+        .arg(
+            Arg::with_name("url_denylist")
+                .long("dont-scan")
+                .value_name("URL")
+                .takes_value(true)
+                .multiple(true)
+                .use_delimiter(true)
+                .help(
+                    "URL(s) to exclude from recursion/scans",
+                ),
+        )
         .arg(
             Arg::with_name("headers")
                 .short("H")
